@@ -1,31 +1,30 @@
 package Modern::Perl;
 
-use strict;
-use warnings;
-
 =head1 NAME
 
 Modern::Perl - enable all of the features of Modern Perl with one command
 
 =head1 VERSION
 
-Version 1.02
+Version 1.03
 
 =cut
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
-use 5.10.0;
+use 5.010_000;
 
 use strict;
 use warnings;
 
+use mro     ();
 use feature ();
 
 sub import {
     warnings->import();
     strict->import();
-    feature->import(':5.10');
+    feature->import( ':5.10' );
+    mro::set_mro( scalar caller(), 'c3' );
 }
 
 =head1 SYNOPSIS
@@ -37,8 +36,9 @@ instead write only one:
     use Modern::Perl;
 
 For now, this only enables the L<strict> and L<warnings> pragmas, as well as
-all of the features available in Perl 5.10.  In the future, it will include
-additional CPAN modules which have proven useful and stable.
+all of the features available in Perl 5.10.  It also enables C3 method
+resolution order; see C<perldoc mro> for an explanation.  In the future, it
+will include additional CPAN modules which have proven useful and stable.
 
 See L<http://www.modernperlbooks.com/mt/2009/01/toward-a-modernperl.html> for
 more information, and L<http://www.modernperlbooks.com/> for further discussion
@@ -90,7 +90,9 @@ L<http://search.cpan.org/dist/Modern-Perl/>
 
 Damian Conway (inspiration from L<Toolkit>), Florian Ragwitz
 (L<B::Hooks::Parser>, so I didn't have to write it myself), chocolateboy (for
-suggesting that I don't even need L<B::Hooks::Parser>, at least for now).
+suggesting that I don't even need L<B::Hooks::Parser>, at least for now),
+Damien Learns Perl, David Moreno, and Evan Carroll for reporting bugs and
+requesting features.
 
 =head1 COPYRIGHT & LICENSE
 
